<?php

require_once '../include/DbHandler.php';
require_once '../include/PassHash.php';
require '../libs/Slim/Slim.php';

$db = new DbHandler();

if($db->checkDatabase())
    echo 'It seems alright!';
else
{
    echo "<form action='newDatabase.php' method='GET'>";
    echo "<label>Prefix for new database:";
    echo "<input name='prefix'/></label>";
    echo "<input type='submit'/>";
    echo "</form>";
}