<?php
/**
 * Created by PhpStorm.
 * User: Enver
 * Date: 19.03.2017.
 * Time: 21:30
 */
require_once '../include/DbHandler.php';
require_once '../include/PassHash.php';
require '../libs/Slim/Slim.php';

$db = new DbHandler();

$db->makeNewDatabase($_GET["prefix"]);

echo "New db created!";