.centerH
{
    margin: 0 auto;
    display: inline-block;
}

.container
{
    text-align: center;
    padding-top: 20px;
    padding-bottom: 20px;
}

nav {
    display: inline-block;
}

table {
    font-family: arial, sans-serif;
    border-collapse: collapse;
    width: 100%;
}

td, th {
    border: 1px solid #dddddd;
    text-align: left;
    padding: 8px;
}

tr:nth-child(even) {
    background-color: #dddddd;
}