
CREATE TABLE `ccwiz_calls` (
  `UserId` int(11) NOT NULL,
  `FromToWho` varchar(50) COLLATE utf8_bin NOT NULL,
  `RecordedCall` mediumtext COLLATE utf8_bin NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_calls`
--

INSERT INTO `ccwiz_calls` (`UserId`, `FromToWho`, `RecordedCall`) VALUES
(1, '1204', '[]'),
(1, '1204', '[]'),
(1, '1204', '[]'),
(1, '1204', '[]'),
(1, '1204', '[]'),
(1, '1204', '[]');

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_categories`
--

CREATE TABLE `ccwiz_categories` (
  `Id` int(11) NOT NULL,
  `Title` varchar(50) COLLATE utf8_bin NOT NULL,
  `Enabled` tinyint(1) NOT NULL DEFAULT '1'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_categories`
--

INSERT INTO `ccwiz_categories` (`Id`, `Title`, `Enabled`) VALUES
(2, 'Vehicles', 1),
(3, 'MGA', 1),
(4, 'MI', 1),
(5, 'Finance', 1),
(6, 'SSI', 1),
(7, 'Exchange', 1),
(8, 'EW', 1),
(9, 'Autocard', 1),
(10, 'AMC', 1);

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_categoriesblocks`
--

CREATE TABLE `ccwiz_categoriesblocks` (
  `UserId` int(11) NOT NULL,
  `CategoryId` int(11) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_locations`
--

CREATE TABLE `ccwiz_locations` (
  `UserId` int(11) NOT NULL,
  `Location` varchar(250) COLLATE utf8_bin NOT NULL,
  `DateAdded` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_locations`
--

INSERT INTO `ccwiz_locations` (`UserId`, `Location`, `DateAdded`) VALUES
(1, 'Location[network 44,204158,17,679952 acc=25 et=+3h21m33s680ms {Bundle[mParcelledData.dataSize=768]}]', '2017-04-12 17:52:51'),
(1, 'Location[network 44,204158,17,679952 acc=42 et=+3h26m58s68ms {Bundle[mParcelledData.dataSize=576]}]', '2017-04-12 17:56:28'),
(1, 'Location[network 44,204158,17,679952 acc=42 et=+3h26m58s68ms {Bundle[mParcelledData.dataSize=576]}]', '2017-04-12 17:58:59');

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_messages`
--

CREATE TABLE `ccwiz_messages` (
  `UserId` int(11) NOT NULL,
  `FromWho` varchar(50) COLLATE utf8_bin NOT NULL,
  `Message` varchar(255) COLLATE utf8_bin NOT NULL,
  `DateAdded` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_messages`
--

INSERT INTO `ccwiz_messages` (`UserId`, `FromWho`, `Message`, `DateAdded`) VALUES
(1, 'globfone', 'test test', '2017-04-11 19:35:35');

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_models`
--

CREATE TABLE `ccwiz_models` (
  `Id` int(11) NOT NULL,
  `Title` varchar(50) COLLATE utf8_bin NOT NULL,
  `Enabled` tinyint(1) NOT NULL DEFAULT '1'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_models`
--

INSERT INTO `ccwiz_models` (`Id`, `Title`, `Enabled`) VALUES
(1, 'Default', 1),
(2, 'All', 1),
(3, 'Diesel', 1),
(4, 'Petrol', 1),
(5, 'Swift', 1),
(6, 'Dzire', 1),
(7, 'Alto', 1),
(8, 'WagonR', 1),
(9, 'Competitio', 1);

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_pushnotifications`
--

CREATE TABLE `ccwiz_pushnotifications` (
  `Title` varchar(50) COLLATE utf8_bin NOT NULL,
  `Message` varchar(256) COLLATE utf8_bin NOT NULL,
  `DateAdded` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_questions`
--

CREATE TABLE `ccwiz_questions` (
  `Id` int(11) NOT NULL,
  `CategoryId` int(11) NOT NULL,
  `ModelId` int(11) NOT NULL,
  `TechnologyId` int(11) NOT NULL,
  `DifficultyLevel` tinyint(4) NOT NULL,
  `QuestionText` varchar(250) COLLATE utf8_bin NOT NULL,
  `Option1` varchar(50) COLLATE utf8_bin NOT NULL,
  `Option2` varchar(50) COLLATE utf8_bin NOT NULL,
  `Option3` varchar(50) COLLATE utf8_bin DEFAULT NULL,
  `Option4` varchar(50) COLLATE utf8_bin DEFAULT NULL,
  `RightOption` tinyint(4) NOT NULL,
  `DateAdded` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `DateModified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_questions`
--

INSERT INTO `ccwiz_questions` (`Id`, `CategoryId`, `ModelId`, `TechnologyId`, `DifficultyLevel`, `QuestionText`, `Option1`, `Option2`, `Option3`, `Option4`, `RightOption`, `DateAdded`, `DateModified`) VALUES
(1, 6, 2, 1, 1, 'In automobile customer satisfaction is measured by?', 'J D Power', 'TNS TCS', 'Both A & B', 'None of the above', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(2, 6, 2, 1, 1, 'J D Power conducts the survey on?', 'Sales & Service', 'Product quality', 'Buyers behaviour', 'All the above', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(3, 6, 2, 1, 1, 'Who is the winner of JD Power SSI in 2016 is?', 'MSIL', 'Hyundai', 'Honda', 'Toyota', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(4, 6, 2, 1, 1, 'Which survey is conducted by J D Power? ', 'SSI', 'CSI', 'IQS & APEAL', 'All the above', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(5, 2, 2, 1, 1, 'How many production plants are there of MSIL?', '1', '2', '3', '4', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(6, 2, 2, 1, 1, 'Maruti Suzuki India ltd. Vision & Core value is?', 'Way of life', 'Count on us', 'Creating customer delight & shareholders wealth', 'All the above', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(7, 2, 2, 1, 1, 'India’s first affordable people’s car is?', 'Maruti 800', 'Tata Nano', 'Alto', 'None of the above', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(8, 2, 2, 1, 1, 'The number two automaker of India is?', 'MSIL', 'Tata  ', 'Hyundai', 'Honda', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(9, 2, 2, 1, 1, 'Highest selling car of year 2016 is?', 'Eon', 'Kwid', 'Baleno', 'Alto', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(10, 2, 3, 1, 1, '.................... is a SUV?', 'Hexa', 'Innova', 'Captiva', 'Xylo', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(11, 2, 2, 1, 1, 'Safety system in a car is of?', 'Active safety', 'Passive safety', 'Dynamic safety', 'Both A & B', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(12, 2, 3, 1, 1, 'DDIS stands for?', 'Direct diesel injection system', 'Diesel direct ignition system', 'Diesel direct injection system', 'Direct diesel ignition system', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(13, 2, 4, 1, 1, 'K-Series engine is available in……. Types?', '1', '2', '3', '4', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(14, 2, 2, 1, 1, 'With respect to tyre size what does R stand for?', 'Radius of the rim', 'Radial tyres', 'Diameter of the rim', 'Width of the tyre', 1, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(15, 2, 2, 1, 1, 'Who measures the fuel efficiency figures in India?', 'VRDE', 'I-CATS', 'ARAI', 'None of the above', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(16, 2, 4, 1, 1, 'Feature which is present in Alto-K10 Vxi but not in Lxi is?', 'Accessory socket', 'Remote fuel lid opener', 'Remote boot lid opener', 'Electronic tripmeter', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(17, 2, 2, 1, 1, 'Suspension is responsible for?', 'Good handling', 'Good ride', 'Absorbs road bumps', 'All the above', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(18, 2, 2, 4, 1, 'Which of the following is a active safety feature?', 'Tubeless tyres', 'ABS & EBD', 'Horn', 'All the above', 1, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(19, 5, 1, 1, 1, 'Pre-closure of loan before the total loan tenure period is known as?', 'Loan closure', 'Final closure', 'Fore closure', 'It’s a sanctioning process in auto loan', 1, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(20, 3, 1, 1, 1, 'Which of the following is the benefit of Maruti Genuine accessory ?', 'Helps in selling more number of cars', 'Benefits customers ', 'Helps to earn more', 'All the above', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(21, 2, 3, 1, 1, 'The Swift Vdi is equipped with?', 'Electronic power stearing', 'Anti lock breaking system', 'Rear fog light', 'All the above', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(22, 2, 2, 1, 1, 'U-VA is a hatch-back variant of which car?', 'Cruze', 'Spark', 'Aveo', 'Beat', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(23, 2, 2, 1, 1, 'Santa Fe launched by?', 'Hyundai', 'Honda', 'Mahindra', 'Tata', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(24, 2, 2, 1, 1, 'Active-Dynamic-Emotion is the variant name of?', 'Verna', 'Superb', 'Punto', 'VW polo', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(25, 2, 3, 1, 1, 'D-4-D is a diesel engine technology of?', 'Honda', 'Ford', 'Toyota', 'Fiat', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(26, 2, 2, 1, 1, 'Steering mounted audio control is a?', 'Safety feature', 'Luxury feature', 'Convinience feature', 'Safety & convinence', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(27, 2, 2, 1, 1, 'Brand AUDI is owned by which automobile group?', 'Fiat', 'General Motors', 'Mercedes Benz', 'Volkswagon', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(28, 2, 2, 1, 1, 'Terrano is car from which brand?', 'Nissan', 'Renault', 'Cheverolet', 'Volkswagon', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(29, 2, 2, 1, 1, 'Which company owns Jaguar Brand?', 'Volkswagon', 'Cheverolet', 'Mercedes Benz', 'Tata', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(30, 2, 3, 1, 1, 'What is the unit to measure torque in a car?', 'Newton meter', 'Newton', 'Kg', 'Inches', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(31, 2, 2, 1, 3, 'Genesis is sub brand of which company?', 'Honda', 'Hyundai', 'Fiat', 'Volkswagon', 1, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(32, 2, 4, 1, 1, 'Maruti K series engines have four cylinders?', 'True', 'False', 'NULL', 'NULL', 1, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(33, 2, 2, 1, 1, 'Car with the DOHC Engine is?', 'Wagon R', 'Alto', 'Swift', 'All the above', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(34, 2, 4, 1, 1, 'When was Maruti 800 car launched?', '1980', '1982', '1983', '1985', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(35, 2, 4, 1, 1, 'When was Maruti Omni launched?', '1982', '1983', '1984', '1985', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(36, 2, 4, 1, 1, 'When was Maruti Wagon R launched?', '1994', '1995', '1997', '1999', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(37, 2, 2, 1, 1, 'where is the registered office of Maruti Suzuki India Ltd. ?', 'New Delhi', 'Mumbai', 'Chennai', 'Hyderabad', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(38, 2, 2, 1, 1, 'In which year has company chnged its name from Maruti udyog Ltd. To Maruti Suzuki India Ltd?', '2007', '2008', '2006', '2004', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(39, 6, 2, 1, 1, 'What is the full form of SSI?', 'Sales & service index', 'Sales & service industry', 'Sales & service index', 'Sales, service & insurance', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(40, 6, 2, 1, 1, 'The segmentation of the cars by the SIAM is done by their?', 'Shape', 'Width', 'Hieght', 'Length', 3, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(41, 6, 2, 1, 1, 'SIAM stands for?', 'Social India Auto Maker', 'Society Of Indian Auto Maker', 'Society Of Indian Automobile Manufacturer', 'Society Of Indian Autoparts Maker.', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(42, 2, 2, 1, 1, 'The right sequence of a four stroke engine is?', 'Intake-Power-Compression-Exhaust', 'Intake-Compression-Exhaust-Power', 'IntakeNULLCompressionNULLPowerNULLExhaust', 'PowerNULLCompressionNULLIntakeNULLExhaust', 1, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(43, 2, 2, 1, 1, 'Turbo Charger runs by the help of?', 'Exhaust gases', 'Intake air', 'Engine power', 'All the above', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(44, 2, 3, 1, 1, 'Turbo Charger & Intercooler available in?', 'Diesel Engines', 'Petrol Engines', 'Bothe A & B', 'None of the above', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(45, 2, 3, 1, 3, 'Greater supply of air to engine which results in higher power, milege, & cleaner exhaust is a function of?', 'K-series', 'Turbocharger', 'VVT', 'Cylinders', 1, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(46, 2, 4, 1, 3, 'Technology which is used by Maruti petrol cars for the fuel supply is?', 'MPFI', 'VIS', 'SMPFI', 'DDIS', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(47, 2, 2, 1, 3, 'In which mode we can start the auto transmission cars of MSIL?', 'P-mode', 'D-mode', 'NNULLnode', 'LNULLmode', 0, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(48, 2, 2, 1, 3, 'Maruti Suzuki Omni & Gypsy Have Which Stearing system?', 'Rack & Pionion', 'Ball & Nut', 'Rack & Pinion mechanical', 'both A & B', 1, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(49, 2, 2, 1, 3, 'The differences in petrol & Diesel engine operation is?', 'No spark plug in deisel engine', 'Only air will enter in intake mode', 'Both A & B', 'None of the above', 2, '2017-04-11 14:46:28', '2017-04-11 14:46:28'),
(50, 2, 2, 1, 3, 'Second most environment-friendly car in the world is?', 'Honda Jazz', 'Nissan Micra', 'Maruti Swift', 'Maruti Celerio', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(51, 2, 2, 5, 1, ' Driver side SRS airbag is available as an option in?', 'Swift', 'Alto', 'Omni', 'Eco', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(52, 2, 2, 1, 3, '“Always around you” is a service programme of?', 'Cheverolet', 'Tata', 'Hyundai', 'Ford', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(53, 2, 2, 1, 3, 'Drive simpler, live better is a tag line of?', 'Skoda Fabia', 'Nissan Micra', 'Ford Figo', 'VW polo', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(54, 2, 4, 1, 3, 'VTVT Technology is called?', 'Variable Timing Variable Train', 'Valve Timing Variable Train', 'Variable Timing Valve Train', 'Variable Train Valve Timing', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(55, 2, 4, 1, 3, 'Which of the following statement is correct for Maruti Alto?', 'Front console with cup holders is available in Lx ', 'Fabric seats is only available in Lxi', 'Remote fuel lid opener available in Lxi only', 'All the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(56, 2, 2, 1, 3, 'Fuel type used in i-GPI technology is?', 'Petrol', 'CNG', 'LPG', 'Diesel', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(57, 2, 4, 1, 3, 'Which of the following feature is not available in i-10 1.2 kappa2 VTVT Asta?', 'Dual Airbags', 'ABS', 'Audio system remote', 'Alloy wheels', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(58, 2, 2, 1, 3, 'Car with the lowest ground clearance in the segment is?', 'VW Polo', 'Nissan Micra', 'Ford Figo', 'Hyundai iNULL10', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(59, 2, 2, 1, 3, 'Which of the following car is having Automatic Climate Control AC?', 'Swift', 'Beat', 'Alto', 'Omni', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(60, 2, 2, 1, 3, 'Which of the car is having roof rails?', 'Wagon R', 'Beat', 'Both A & B', 'None of the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(61, 6, 2, 1, 3, 'Euro NCAP is related with?', 'Safety  ', 'Security', 'Comfort', 'All the above', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(62, 3, 2, 1, 3, 'MGA can be used to make the product more attractive & desirable at which stage of sales process?', 'Opening', 'Product presentaion', 'Need assessment', 'Both B & C', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(63, 2, 2, 1, 3, 'Engine rpm indicates the revolution per second of?', 'Camshaft', 'Valves', 'Crankshaft', 'Conecting rod', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(64, 2, 3, 1, 3, 'Glow plugs are used in?', 'Diesel engines', 'Petrol engines', 'Duo engines', 'All the above', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(65, 2, 2, 1, 3, 'A higher power to weight ratio results in greater acceleration & higher fuel efficiency?', 'True', 'False', 'true in case of diesel engines only', 'It is indefinite', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(66, 2, 2, 1, 5, 'FGT engine is available in?', 'Ritz', 'Swift', 'Dezire', 'All the above', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(67, 2, 2, 1, 5, 'Feature which maximized vehicle security is?', 'ABS', 'Airbags', 'INULLCATS', 'All the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(68, 2, 3, 1, 5, 'Ford Figo Diesel engine is known as?', 'Duratec', 'Duratorq', 'Quadrajet', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(69, 2, 2, 1, 5, 'Car which comes with the turning radius of 5.4 mtr is?', 'i-10', 'i-20', 'Etios Liva', 'GNULL Punto', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(70, 2, 2, 1, 5, 'Ground clearance of the Honda City & VW Vento is?', '160 & 168 respectively', '165 & 160 respectively', '160 for both cars', '165 for both cars', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(71, 5, 2, 1, 1, 'Hypothicaton means…?', 'Ownership with possession', 'Ownership without possession', 'Process of taking loan', 'All the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(72, 4, 2, 1, 1, 'Correct discount structure for NCB per year is..?', '20-30-40-50-60', '20-25-35-45-50', '20NULL25NULL30NULL35NULL40', '10NULL20NULL30NULL40NULL50', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(73, 4, 2, 1, 1, 'Age of the car is?', '10 years', '20 years', '30 years', '25 years', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(74, 7, 2, 1, 1, 'Auto terrace is a exchange program of?', 'Hyundai', 'Mahindra', 'Honda', 'Cheverolet', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(75, 7, 2, 1, 1, 'India\'s largest used car dealer is?', 'First Choice', 'H Promise', 'True Value', 'Auto Terrace', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(76, 2, 2, 1, 1, 'How many variants does Vitara Brezza comes in?', '3', '4', '5', '6', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(77, 2, 2, 1, 1, 'How many color options does Vitara Brezza has in dual tone?', '3', '2', '4', '1', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(78, 2, 2, 1, 3, 'what is the ranking of India in world automobile market in terms of sales?', '3rd', '4th', '5th', '2nd', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(79, 2, 4, 1, 1, 'K series engines are linked to which manufacturer in India?', 'Ford', 'Honda', 'Maruti  ', 'Nissan', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(80, 2, 3, 1, 1, 'Name the hatchback which was introduced with \" DDIS125\" engine?', 'Eon', 'Swift', 'Beat', 'Celerio', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(81, 2, 2, 1, 3, 'Which of these weights is maximum?', 'Dry weight', 'Kerb weight', 'Gross weight', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(82, 2, 2, 1, 1, 'What is the unit to measure boot space in cars?', 'Kilogram', 'Watts', 'Liters', 'Newton', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(83, 2, 2, 1, 3, 'Mahindra owns which foreign car company?', 'SsangYong', 'Fiat', 'SAAB', 'Jaguar', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(84, 2, 2, 1, 3, 'which company owns Datsun brand?', 'Peugeot', 'Volkwagon', 'Suzuki', 'Nissan', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(85, 2, 3, 1, 3, 'Creta shares diesel engine with..?', 'Verna & i-20', 'Santa- Fe & i-20', 'Verna & Xcent', 'iNULL10 & iNULL20', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(86, 2, 2, 1, 5, 'Who is the manufacturer of the car named \"countryman\"?', 'Mercedes Benz', 'Audi', 'Porsche', 'Mini', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(87, 2, 2, 1, 3, 'What is the wheel base of Dezire?', '2430mm', '2470mm', '2600mm', '2405mm', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(88, 2, 2, 1, 5, 'What is the technology responsible for prevention from unauthorized ignition from any ther key named ?', 'SHVS', 'EBD', 'Keyless entry', 'INULLCATS', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(89, 5, 2, 1, 3, 'What is the amount paid in installments for loan called?', 'Margin money', 'Interest', 'EMI', 'Down payment', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(90, 7, 2, 1, 3, 'How many points are there on the True Value evaluation checklist?', '100', '110', '90', '120', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(91, 7, 2, 1, 3, 'What is the range of Kilometers that Ture Value accepts for exchange of old car?', '100000 Kms', '1000000Kms', '50000Kms', '10000Kms', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(92, 7, 2, 1, 1, 'How many years warranty is given on Maruti True Value used cars when sold?', '6months', '1 year', '3 years', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(93, 4, 2, 1, 1, 'When was Maruti Insurance launched?', '2005', '2003', '2002', '2004', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(94, 2, 2, 1, 3, 'How Many Automatic gear shift models are there in Maruti line up?', '2', '4', '3', '6', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(95, 2, 2, 1, 3, 'What is the market share of MSIL as of January 2017?', '0.21', '0.39', '0.51', '0.49', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(96, 4, 2, 1, 3, 'What is the achievement of MI in 2005 in terms of number of insurances sold?', '1million', '2million', '3million', '5million', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(97, 2, 2, 1, 5, 'Who was the very first owner of a maruti car?', 'Satpal Singh', 'Khushpal Singh', 'Harpal Singh', 'Manjot Singh', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(98, 2, 4, 1, 3, 'When did first Maruti Gypsy rolled out?', '1984', '1983', '1985', '1988', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(99, 2, 4, 1, 3, 'When did first Maruti Esteem rolled out?', '1990', '1991', '1998', '1994', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(100, 2, 2, 1, 5, 'Maruti launched on road assistance service in the year?', '1996', '1994', '1998', '2000', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(101, 2, 4, 1, 3, 'How many types of transmissions are available in Wagon R?', '1', '3', '2', 'None of the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(102, 2, 3, 1, 3, 'SHVS technology comes with which enigine?', 'Petrol', 'Diesel  ', 'Both A & B', 'Duo', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(103, 5, 2, 1, 3, 'Advantages of Maruti finance are…?', 'Customer delight', 'Wide choice of financiers', 'One stop solution for customer\'s needs', 'All the above', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(104, 4, 2, 1, 3, 'Advantages of Maruti Insurance are…?', 'Near cash-less accident repairs', 'Seamless services across the nation', 'Easy transfer of no claim bonus', 'All the above', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(105, 2, 2, 5, 3, 'Airbags are example of…?', 'Active safety', 'Passive safety', 'Dynamic Safety', 'All the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(106, 2, 2, 1, 3, 'Examples of active safety are..?', 'ABS & EBD', 'Monocoque body', 'Airbags', 'Seatbelts', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(107, 2, 2, 1, 3, 'According to SIAM, what is the length defined for compact car?', '300-3400 mm', '3400-3600 mm', '3600NULL4000 mm', 'None of the above', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(108, 2, 2, 1, 3, 'What does EBD stands for?', 'Electric boost developer', 'Electronic breakforce distribution', 'ElectroNULLmagentic break distribution', 'ElectroNULLmagnetic break damper', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(109, 2, 2, 1, 3, 'The distance between the front tyre centerline is? ', 'wheelbase', 'Front track', 'Rear track', 'Ground clearance', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(110, 9, 2, 1, 1, 'What is the joining bonus for Maruti autocard?', '200 points', '100 points', '500 points', '10 points', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(111, 2, 2, 1, 3, 'Which is the \"India Car of the year\" (ICOTY) 2017?', 'Maruti Suzuki Swift', 'Hyundai i-10', 'Ford Figo', 'Maruti Suzuki Vitara Brezza', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(112, 2, 3, 1, 3, 'What is the power deilivered by Vitara Brezza?', '89 bhp/200Nm', '74 bhp/190 Nm', '86 bhp/112 Nm', '99bhp/215 Nm', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(113, 2, 2, 1, 3, 'What does TECT stands for in Maruti Suzuki ?', 'Turbine Engine Component Technology', 'Total Effective Control Technology', 'The Evolution of Cooperation & Training', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(114, 2, 4, 1, 5, 'Name the engine in Maruti Suzuki Swift.?', 'K10 B series', '1.3 L K series', 'K12 B series', 'None of the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(115, 2, 2, 1, 5, 'The 2017 Mobil1 CNB Viewers\' Choice Car of the year is?', 'Maruti Suzuki Dezire', 'Maruti Suzuki Vitara Brezza', 'Maruti Suzuki Ciaz', 'Hyundai iNULL10', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(116, 2, 2, 1, 1, 'What is the brand name given to the premium vehivle line up from Maruti Suzuki ?', 'Hexa', 'Nexa', 'Genesis', 'Lexus', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(117, 2, 3, 1, 3, 'What is the full form of SHVS ?', 'Smart hybrid Vehicle by suzuki', 'Smart Hybrid Vehicle system', 'Simple Hybrid Vehicle System', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(118, 2, 2, 1, 3, 'What is the boot space of Maruti Suzuki Dezire Tour ?', '316 L', '460 L', '464 L', '510 L', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(119, 2, 4, 1, 3, 'What is the power of Alto K10\'s  engine ?', '67bhp', '68bhp', '53bhp', 'None of the above', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(120, 2, 4, 1, 5, 'What are/is the feature not present in Alto K10 ? ', 'Airbags', 'Middle rear three point seatbelt', 'Engine immobilizer', 'A & B only', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(121, 2, 4, 1, 3, 'Turning radius of Wagon R is ?', '5.4 m', '4.7 m', '4.2 m', '4.6 m', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(122, 2, 2, 1, 3, 'what is the name of model recently launched in Maruti Suzuki Nexa?', 'Baleno', 'Baleno RS', 'Ignis', 'SNULLcross', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(123, 2, 2, 1, 5, 'What is the growth percentage of Maruti Suzuki India Ltd. In 2016 vs 2015?', '2-3%', '3-4%', '6NULL7%', 'No growth', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(124, 2, 2, 1, 5, 'what is the production capacity of MSIL annually ?', '14,50,000 cars', '12,00,000 cars', '14,00,000 cars', 'None of the above', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(125, 2, 2, 1, 3, 'Which of the following are the straight competitors of Deizre ?', 'Honda Amaze', 'Tata Zest', 'VW Ameo', 'All the above', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(126, 2, 2, 1, 3, 'How many Maruti Suzuki dealerships are there in India ?', '2000', '4500', '1643', '1450', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(127, 2, 2, 1, 3, 'Who is the chairman of MSIL ?', 'Mr. D. S. Brar', 'Mr. R. C. Bhargava', 'Mr. Osamu Suzuki', 'Mr. R. S. Kalsi', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(128, 2, 4, 1, 3, 'what is the claimed mileage for Alto 800 petrol ?', '22.7 Kmpl', '23.5 Kmpl', '23.7 Kmpl', '33.4 Kmpl', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(129, 8, 2, 1, 1, 'What is the coverage of warranty in months without extended warranty ?', '12 months', '18 months', '36 month', '24 months', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(130, 8, 2, 1, 1, 'How many months are added to the extended warranty of car if taken the \"EW Platinum\" ?', '6 months', '36 months', '24 months', '12 months', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(131, 8, 2, 1, 1, 'What is the coverage in kilometers of \"EW Platinum\' warranty ?', '60,000 Kms', '40,000 Kms', '1,00,000 Kms', '80,000 Kms', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(132, 3, 2, 1, 3, 'What does tyre pressure monitoring system does in a car?', 'Monitors the air pressure in tyres', 'Regulates the air pressure in tyres', 'only A', 'both A & B', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(133, 3, 2, 1, 3, 'What is i-create known for?', 'Maruti genuine accessories', 'Swift body kit', 'Vitara Brezza customization ', 'All the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(134, 3, 2, 1, 3, 'What does heads up display does in a car ?', 'Used to relax head while driving', 'Used to project videos to car windshield', 'used to project necessary information to the winds', 'None of the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(135, 2, 4, 1, 3, 'How many variants of Omni are there ?', '4', '2', '3', '5', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(136, 2, 3, 1, 1, 'How many SHVS models does Maruti has on offer ?', '1', '2', '4', '5', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(137, 2, 2, 1, 3, 'Which is the model  shifted to Maruti\'s premium dealership Nexa from the normal one ?', 'Swift Dezire', 'Ciaz', 'Gypsy', 'Swift', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(138, 2, 2, 1, 1, 'Maruti Suzuki Ertiga is also known as ?', 'MUV', 'MPV', 'LUV', 'SUV', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(139, 2, 4, 1, 3, 'What was the Vxi variant of Wagon R known as before it mreged to the brand name Wagon R ?', 'Stingray', 'Zen', 'Celerio', 'ANULLstar', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(140, 2, 3, 1, 3, 'Maruti Brezza is exported to …?', 'Asia, Africa, Latin America & Middle East', 'Asia, Africa & Middle East', 'Asia, Europe, Latin America', 'Asia & Middle East', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(141, 2, 2, 1, 3, 'Which car has been awarded the \" Autocar car of the year\" ?', 'Hyundai Creta', 'Ford Ecosports', 'Vitara Brezza  ', 'Mahindra KUV 100', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(142, 2, 2, 1, 3, 'Which is the \"Autocar compact SUV of the year\" ?', 'Hyundai Creta', 'Ford Ecosports', 'Vitara Brezza', 'Mahindra TUV 300', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(143, 2, 4, 1, 3, 'What is the updated wheelbase of Alto 800 facelift 2016 ?', '3430 mm', '3350 mm', '3450 mm', '3400 mm', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(144, 2, 4, 1, 3, 'What is the difference in Alto 800 facelift 2016 exterior than pre-face lift ?', 'Two tone colors', 'Passenger side wing mirrors', 'Both A & B', 'Only B', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(145, 2, 2, 1, 3, 'What does NCAP stands for ?', 'National Corporation for Agricultural Poicies', 'National Car Assessment Program', 'New car Assessment Program', 'None of the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(146, 3, 2, 1, 3, 'What is the option for rear seat entertainment in MGA ?', 'Rear seat entertainment android', 'Rear seat infotainment adroid', 'Rear seat arm rest', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(147, 3, 2, 1, 3, 'what is the option available in Ciaz which normally come in luxury cars ?', 'Touch screen music player', 'Reverse parking sensor', 'Sun blinds', 'Keyless entry', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(148, 2, 4, 1, 3, 'MSIL car which has 3 valves per cylinder is…?', 'Alto K10', 'Swift', 'Maruti 800', 'None of the above', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(149, 2, 4, 1, 1, 'Which variant in Alto 800 has internally adjustable ORVM ?', 'Lx', 'Std.', 'LX(O)', 'Lxi', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(150, 2, 4, 5, 1, 'Driver side airbag is present in which variant of Alto 800?', 'Std(O)', 'Lxi', 'Vxi', 'None of the above', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(151, 3, 4, 1, 1, 'Sliver accent interior door handles are present in ?', 'Alto 800 Std(O)', 'Alto 800 LX(O)', 'Alto 800 Vxi', 'All the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(152, 3, 4, 1, 1, 'Rear parcel tray is standard fitment in ?', 'Alto 800 Lxi', 'Alto 800 Lxi(O)', 'Alto 800 Vxi(O)', 'All the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(153, 2, 4, 1, 1, 'Remote keyless entry is the feature persent in ?', 'Alto 800 Std(O)', 'Alto 800 Lxi(O)', 'Alto 800 LX(O)', 'Alto 800 Vxi', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(154, 2, 4, 1, 3, 'Which car has a 3 cylinder engine?', 'Maruti Suzuki Alto 800', 'Hyundai Eon', 'Both A & B', 'None of the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(155, 2, 4, 1, 3, 'Which of the cars have both petrol and CNG options as a fuel type ?', 'Maruti Suzuki Alto 800', 'Hyundai Eon', 'Renault Kwid', 'Datsun Redigo', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(156, 2, 4, 1, 3, 'What is the wheelbase of Alto 800?', '2380 mm', '2360 mm', '2422 mm', '2348 mm', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(157, 2, 4, 1, 3, 'What is the feature that makes Alto 800 superior to Hynudai Eon in terms of comfort and hassel free drive?', 'Longer wheel base', 'Internally adjustable ORVM', 'Diagnal Shift assist', 'More mileage', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(158, 2, 4, 1, 3, 'Turning radius of Alto 800 is more than that of Renault Kwid .?', 'True', 'False', 'NULL', 'NULL', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(159, 2, 4, 1, 3, 'Wheel base of Alto k10 is more than Alto 800?', 'True', 'False', 'NULL', 'NULL', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(160, 3, 4, 1, 3, 'Chrome front grill is standard on all variants of Alto K10?', 'True', 'False', 'NULL', 'NULL', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(161, 3, 4, 1, 3, 'Body colored door handles are standard in ?', 'Alto K10 Vxi(O)', 'Alto K10 Vxi( AGS)', 'Alto K10 Vxi', 'All the above', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(162, 2, 4, 1, 3, 'Which of the following cars have a tachometer ?', 'Hyundai Eon', 'Renault Kwid', 'Alto k10  ', 'None of the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(163, 2, 4, 4, 3, 'Which variant in Wagon R doesn’t has ABS ?', 'Lxi(O)', 'Lxi(O) Green', 'Vxi(O) AGS', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(164, 2, 4, 1, 3, 'Wheel base of Wagon R is ?', '3585 mm', '3599 mm', '3569 mm', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(165, 2, 4, 1, 3, 'The kerb weight of Swift petrol car is?', '1415 Kgs', '1505 Kgs', '965 Kgs', '1060 kgs', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(166, 2, 2, 1, 3, 'Turning radius of Swift is?', '4.4 mtrs', '4.5 mtrs', '4.8 mtrs', '5 mtrs', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(167, 2, 2, 1, 1, 'Ground clearance of Swift is ?', '165 mm', '170 mm', '180 mm', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(168, 2, 4, 1, 3, 'What is the maximum torque attained in Swift Zxi?', '140Nm@4000 rpm', '114Nm@4000 rpm', '110Nm@4000 rpm', '115Nm@4000 rpm', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(169, 2, 2, 1, 3, 'What is an MID ?', 'Mid size cars', 'Material Identification', 'Multi Information Display', 'Motor insurance database', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(170, 2, 3, 1, 3, 'What is the maximum torque attained in Swift Vdi?', '220Nm@2000 rpm', '160Nm@2000 rpm', '190Nm@3000 rpm', '190Nm@2000 rpm', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(171, 2, 2, 1, 3, 'What is the major difference in safety features in  Polo and i120 Elitein comparison to Swift?', 'No airbags', 'No ABS', 'ABS without EBD', 'No iCATS', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(172, 2, 2, 1, 3, 'What is the difference in wheel size of Swift Vxi and Figo Titanium + ?', 'Swift 14\'\' Figo 15\'\'', 'Swift and Figo both have 15\'\'', 'Swift 15\'\' Figo 14\'\'', 'None of the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(173, 2, 2, 1, 3, 'Headroom comfort is more in Swift then Figo?', 'True', 'False', 'NULL', 'NULL', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(174, 2, 2, 1, 3, 'What is the hieght of Swift ?', '1525mm', '1550mm', '1540mm', '1530mm', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(175, 2, 2, 1, 5, 'What is the unit to measure power in a car?', 'Newton meter', 'Kilogram meter', 'Kilowatts', 'Mili meter', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(176, 2, 2, 1, 3, 'Smart play infotainment system suports navigation tab?', 'True', 'Fasle', 'NULL', 'NULL', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(177, 2, 2, 1, 3, 'Vitara Brezza comes in automatic transmission type.', 'True', 'False', 'NULL', 'NULL', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(178, 2, 3, 1, 5, 'What is the air charging system in Dezire\'s diesel engine?', 'VGT', 'FGT', 'Naturally aspirated', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(179, 2, 2, 1, 5, 'what is a VGT engine system?', 'Vangaurd Information Tech', 'Variable Gas Turbine', 'Variable Geometric Turbocharger', 'Varicore Gas Turbocharger', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(180, 2, 4, 1, 3, 'What are the engine types available in Vitara Brezza?', 'Diesel/Petrol', 'Diesel/Petrol/Hybrid', 'Diesel only', 'Petrol only', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(181, 2, 3, 1, 3, 'what is the maximum torque of vitara Brezza?', '190Nm@ 2000 rpm', '200Nm@1750 rpm', '200Nm@2000 rpm', '220Nm@1750 rpm', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(182, 2, 3, 1, 3, '\"Anti pinch\" driver side auto up/down window is present in ?', 'Dezire & Brezza', 'Only Brezza', 'Only Dezire', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(183, 4, 2, 1, 1, 'Which of the following statement is correct? ', 'Insurance protects the assets', 'Inurance prevents the losses', 'Insurance reduces possibilities of loss', 'Insurance pays when there is loss ', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(184, 4, 2, 1, 1, 'Which of the following statement is correct? ', 'Insurance is a method of sharing the loss of few b', 'Insurance is a method of transferring the risk of ', 'only statement 1', 'Both 1 & 2', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(185, 4, 2, 1, 1, 'In motor insurance certificate of insurance are issued because?', 'Make of the vehicle is not known', 'Year of manufacture is not known', 'Seating capacity of the vehicle is not known', 'it is required by the Motor vehicle act', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(186, 4, 2, 1, 1, 'Which of the following statement is true?', 'Endorsements are issued after the issuance of the ', 'Endorsements are issued at the time of the policy ', 'only statement 2', 'Both 1 & 2', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(187, 4, 2, 1, 1, 'Which of the following statement is true?', 'The schedule of a policy is not altered after the ', 'Changed in the term of the policy are made through', 'Both A & B', 'None of the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(188, 4, 2, 1, 1, 'For getting insurance you need to pay ……….   and get compensated by ………?', 'Compensation, Claims', 'Claims, premium', 'Premium, claims', 'Fees, claims', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(189, 4, 2, 1, 3, 'Perils could be ?', 'Uncertain', 'Certain', 'Definite', 'unlikely', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(190, 4, 2, 1, 1, 'When an insured approaches insurance company to insure his property he needs to fill?', 'Claim form', 'Underwriting form', 'Consideration form', 'Proposal form', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(191, 4, 2, 1, 3, 'Motor insurance covers?', 'Own damage', 'Third party cover', 'Personal accident policy to owner driver', 'All the above', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(192, 4, 2, 1, 1, 'Policy period for a car is ?', '1 year', '2 years', '3 years', '4 years', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(193, 4, 2, 1, 3, 'What factors affect the motor insurance premium ?', 'Location of the vehicle', 'Year of manufaturing', 'Cubic capcity', 'All the above', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(194, 4, 2, 1, 1, 'No claim bonus is benefit given on?', 'Vehicle running condition', 'Good driving', 'Claim free motor parts', 'Passenger of the car', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(195, 4, 2, 1, 1, '………………… is the evidence of insurance contract?', 'Premium receipt', 'Endorsement', 'Ploicy Document', 'Porosal form', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(196, 4, 2, 1, 1, 'Personal accident policy covers?', 'Death', 'Permamnet disability', 'Temporary disability', 'All the above', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(197, 4, 2, 1, 3, 'Which of the following is covered under motor policy by paying extra premium?', 'Geographical extension', 'PA for passengers', 'Accessories', 'All the above', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(198, 4, 2, 1, 3, 'Rates of third party motor premium is fixed by?', 'IRDAI', 'TAC', 'GIC', 'IGMS', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(199, 2, 3, 1, 3, 'Wheelbase of which car is the shortest?', 'Vitara Brezza', 'Hyundai Creta', 'Eco Sport', 'TUV 300', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(200, 2, 3, 1, 5, 'What is the tyre size of Vitara Brezza, Creta, Eco Sport and TUV300 respectively?', '205/65R16; 205/60R16; 215/60R16;  215/75R15', '215/60R16; 205/65R16; 205/60R16; 215/75R15', '215/75R15; 205/65R16; 215/60R16; 205/60R16', 'None of the above', 1, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(201, 2, 3, 1, 3, 'What is the premium feature present in Vitara Brezza that is not in Eco Sport?', 'Reclining rear seats', 'Touch screen music system', 'Voice Control', 'Mood lighting in speedo meter console', 3, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(202, 2, 3, 1, 3, 'What makes Brezza stand ahead in competetion to Creta and Ecosprts?', 'ABS & EBD', '16\'\' alloy wheels', 'Projector Headlamps', 'All the above', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(203, 2, 2, 1, 1, 'Speed sensing door lock is a ?', 'Security feature', 'Comfort feature', 'Safety feature', 'Luxury feature', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(204, 2, 3, 1, 3, 'Cruise control is present in Vitara Brezza ZDI+ only?', 'True', 'False', 'NULL', 'NULL', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(205, 2, 4, 1, 3, 'What is the wheel base of Omni?', '1410mm', '1640mm', '1840mm', '1820mm', 2, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(206, 2, 3, 1, 3, 'Wheelbase of Ertiga is more than TUV 300, Mahindra Bolero and Renault Lodgy?', 'True', 'False', 'NULL', 'NULL', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46'),
(207, 2, 2, 1, 3, 'ORVM mounted turn indicators are present in Ertiga while not in Bolero, Lodgy and TUV 300?', 'True', 'False', 'NULL', 'NULL', 0, '2017-04-11 14:46:46', '2017-04-11 14:46:46');

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_reports`
--

CREATE TABLE `ccwiz_reports` (
  `Id` int(11) NOT NULL,
  `UserId` int(11) NOT NULL,
  `QuestionId` int(11) NOT NULL,
  `Attempts` int(11) NOT NULL,
  `Time` int(11) NOT NULL,
  `DateAdded` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_reports`
--

INSERT INTO `ccwiz_reports` (`Id`, `UserId`, `QuestionId`, `Attempts`, `Time`, `DateAdded`) VALUES
(16, 1, 121, 2, 5, '2017-04-11 14:48:36'),
(17, 1, 127, 4, 4, '2017-04-11 14:48:41'),
(18, 1, 15, 4, 3, '2017-04-11 14:48:45'),
(19, 1, 126, 3, 2, '2017-04-11 14:49:46'),
(20, 1, 146, 4, 3, '2017-04-11 14:49:50'),
(21, 1, 73, 3, 2, '2017-04-11 14:49:53'),
(22, 1, 46, 3, 5, '2017-04-11 14:50:00'),
(23, 1, 168, 1, 2, '2017-04-11 14:50:07'),
(24, 1, 168, 2, 6, '2017-04-11 14:50:07'),
(25, 1, 16, 1, 7, '2017-04-11 17:34:20'),
(26, 1, 16, 2, 9, '2017-04-11 17:34:21'),
(27, 1, 39, 1, 6, '2017-04-11 17:34:29'),
(28, 1, 22, 3, 11, '2017-04-11 17:34:42'),
(29, 1, 3, 2, 4, '2017-04-11 17:54:35'),
(30, 1, 70, 3, 2, '2017-04-11 17:57:43'),
(31, 1, 156, 2, 1, '2017-04-11 17:57:45'),
(32, 1, 124, 4, 2, '2017-04-11 17:57:48'),
(33, 1, 53, 1, 0, '2017-04-11 18:09:19'),
(34, 1, 199, 4, 1, '2017-04-11 18:09:20'),
(35, 1, 157, 2, 0, '2017-04-11 18:09:21'),
(36, 1, 198, 4, 0, '2017-04-11 18:09:23'),
(37, 1, 207, 1, 0, '2017-04-11 18:09:23'),
(38, 1, 35, 2, 0, '2017-04-11 18:09:24'),
(39, 1, 172, 1, 0, '2017-04-11 18:09:25'),
(40, 1, 131, 1, 0, '2017-04-11 18:09:25'),
(41, 1, 23, 2, 0, '2017-04-11 18:09:27'),
(42, 1, 143, 3, 0, '2017-04-11 18:09:27'),
(43, 1, 187, 3, 0, '2017-04-11 18:09:29'),
(44, 1, 8, 2, 0, '2017-04-11 18:09:29'),
(45, 1, 170, 3, 6, '2017-04-12 01:52:53'),
(46, 1, 170, 4, 8, '2017-04-12 01:52:54'),
(47, 1, 57, 2, 4, '2017-04-12 01:52:59'),
(48, 1, 83, 1, 4, '2017-04-12 01:53:07'),
(49, 1, 29, 1, 6, '2017-04-12 01:53:15'),
(50, 1, 123, 4, 4, '2017-04-12 05:15:43'),
(51, 1, 63, 2, 2, '2017-04-12 05:15:45'),
(52, 1, 63, 3, 2, '2017-04-12 05:15:45'),
(53, 1, 130, 3, 2, '2017-04-12 05:15:49'),
(54, 1, 88, 4, 3, '2017-04-12 05:15:52'),
(55, 1, 184, 1, 0, '2017-04-12 05:15:54');

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_sessions`
--

CREATE TABLE `ccwiz_sessions` (
  `Id` int(11) NOT NULL,
  `UserId` int(11) NOT NULL,
  `SessionAdded` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `SessionEnded` timestamp NULL DEFAULT NULL,
  `IpAddress` varchar(50) COLLATE utf8_bin NOT NULL,
  `DeviceInfo` varchar(250) COLLATE utf8_bin NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_sessions`
--

INSERT INTO `ccwiz_sessions` (`Id`, `UserId`, `SessionAdded`, `SessionEnded`, `IpAddress`, `DeviceInfo`) VALUES
(20, 1, '2017-04-10 13:13:12', NULL, 'das21d', 'Kadksh'),
(21, 1, '2017-04-10 13:19:23', NULL, 'das21d', 'Kadksh'),
(22, 1, '2017-04-10 13:20:37', NULL, '109.175.103.133', 'Samsung GT-I9515'),
(23, 1, '2017-04-10 13:21:42', NULL, 'das21d', 'Kadksh'),
(24, 1, '2017-04-10 13:22:07', NULL, 'das21d', 'Kadksh'),
(25, 1, '2017-04-10 13:22:16', NULL, 'das21d', 'Kadksh'),
(26, 1, '2017-04-10 13:22:16', NULL, '109.175.103.133', 'Samsung GT-I9515'),
(27, 1, '2017-04-10 13:40:29', NULL, 'das21d', 'Kadksh'),
(28, 1, '2017-04-10 17:40:47', '2017-04-10 17:43:49', '109.175.103.133', 'Samsung GT-I9515'),
(29, 1, '2017-04-10 17:46:07', '2017-04-10 17:46:36', '109.175.103.133', 'Samsung GT-I9515'),
(30, 1, '2017-04-11 05:18:24', NULL, '109.175.98.205', 'Samsung GT-I9515'),
(31, 1, '2017-04-11 07:35:47', '2017-04-11 07:35:58', '109.163.157.21', 'Samsung GT-I9515'),
(32, 1, '2017-04-11 08:25:55', NULL, '112.133.247.16', 'OnePlus ONEPLUS A3003'),
(33, 1, '2017-04-11 12:31:22', NULL, '195.222.63.198', 'Samsung GT-I9515'),
(34, 1, '2017-04-11 16:43:50', '2017-04-11 16:50:07', '109.175.100.145', 'Samsung GT-I9515'),
(35, 1, '2017-04-11 16:50:17', NULL, '109.175.99.117', 'Samsung GT-I9515'),
(36, 1, '2017-04-11 17:54:27', NULL, '112.133.251.13', 'OnePlus ONEPLUS A3003'),
(37, 1, '2017-04-11 17:57:37', NULL, '109.175.100.145', 'Samsung GT-I9515'),
(38, 1, '2017-04-11 18:09:13', NULL, '109.175.100.145', 'Samsung GT-I9515'),
(39, 1, '2017-04-11 19:31:42', NULL, '109.175.100.145', 'Samsung GT-I9515'),
(40, 1, '2017-04-12 01:52:37', NULL, '112.133.251.90', 'OnePlus ONEPLUS A3003'),
(41, 1, '2017-04-12 04:20:16', NULL, '112.133.251.90', 'OnePlus ONEPLUS A3003'),
(42, 1, '2017-04-12 15:19:47', NULL, '109.175.96.64', 'Samsung GT-I9515'),
(43, 1, '2017-04-13 04:02:54', NULL, '112.133.251.53', 'OnePlus ONEPLUS A3003');

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_technologies`
--

CREATE TABLE `ccwiz_technologies` (
  `Id` int(11) NOT NULL,
  `Title` varchar(50) COLLATE utf8_bin NOT NULL,
  `Enabled` tinyint(1) NOT NULL DEFAULT '1'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_technologies`
--

INSERT INTO `ccwiz_technologies` (`Id`, `Title`, `Enabled`) VALUES
(1, 'Common', 1),
(2, 'AGS', 1),
(3, 'SHVS', 1),
(4, 'Abs & EBD', 1),
(5, 'Airbags', 1);

-- --------------------------------------------------------

--
-- Table structure for table `ccwiz_users`
--

CREATE TABLE `ccwiz_users` (
  `Id` int(11) NOT NULL,
  `ApiKey` varchar(500) COLLATE utf8_bin NOT NULL,
  `Email` varchar(100) COLLATE utf8_bin DEFAULT NULL,
  `PasswordHash` varchar(500) COLLATE utf8_bin NOT NULL,
  `Username` varchar(50) COLLATE utf8_bin NOT NULL,
  `AccessLevel` tinyint(4) NOT NULL,
  `LastOnlineTimestamp` timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `TrackLocation` tinyint(1) NOT NULL DEFAULT '0',
  `SaveMessages` tinyint(1) NOT NULL DEFAULT '0',
  `LogCalls` tinyint(1) NOT NULL DEFAULT '0',
  `MaxDifficultyLevel` tinyint(4) NOT NULL DEFAULT '5',
  `QuestionCount` int(11) NOT NULL DEFAULT '0',
  `Score` int(11) NOT NULL DEFAULT '0',
  `AverageTime` int(11) NOT NULL DEFAULT '0'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `ccwiz_users`
--

INSERT INTO `ccwiz_users` (`Id`, `ApiKey`, `Email`, `PasswordHash`, `Username`, `AccessLevel`, `LastOnlineTimestamp`, `TrackLocation`, `SaveMessages`, `LogCalls`, `MaxDifficultyLevel`, `QuestionCount`, `Score`, `AverageTime`) VALUES
(1, '8cb28cc276e98ddfbbea68457770c2db', NULL, '$2a$10$2e402a9c2169e42071b99u.AYf/ON.HBn4C.pF2NDqpfvzJlWBt.y', 'administrator', 0, '2017-04-13 04:02:57', 1, 1, 1, 5, 45, 12, 3);

--
-- Indexes for dumped tables
--

--
-- Indexes for table `ccwiz_categories`
--
ALTER TABLE `ccwiz_categories`
  ADD PRIMARY KEY (`Id`);

--
-- Indexes for table `ccwiz_models`
--
ALTER TABLE `ccwiz_models`
  ADD PRIMARY KEY (`Id`);

--
-- Indexes for table `ccwiz_questions`
--
ALTER TABLE `ccwiz_questions`
  ADD PRIMARY KEY (`Id`);

--
-- Indexes for table `ccwiz_reports`
--
ALTER TABLE `ccwiz_reports`
  ADD PRIMARY KEY (`Id`);

--
-- Indexes for table `ccwiz_sessions`
--
ALTER TABLE `ccwiz_sessions`
  ADD PRIMARY KEY (`Id`);

--
-- Indexes for table `ccwiz_technologies`
--
ALTER TABLE `ccwiz_technologies`
  ADD PRIMARY KEY (`Id`);

--
-- Indexes for table `ccwiz_users`
--
ALTER TABLE `ccwiz_users`
  ADD PRIMARY KEY (`Id`);

--
-- AUTO_INCREMENT for dumped tables
--

--
-- AUTO_INCREMENT for table `ccwiz_categories`
--
ALTER TABLE `ccwiz_categories`
  MODIFY `Id` int(11) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=11;
--
-- AUTO_INCREMENT for table `ccwiz_models`
--
ALTER TABLE `ccwiz_models`
  MODIFY `Id` int(11) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=10;
--
-- AUTO_INCREMENT for table `ccwiz_questions`
--
ALTER TABLE `ccwiz_questions`
  MODIFY `Id` int(11) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=208;
--
-- AUTO_INCREMENT for table `ccwiz_reports`
--
ALTER TABLE `ccwiz_reports`
  MODIFY `Id` int(11) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=56;
--
-- AUTO_INCREMENT for table `ccwiz_sessions`
--
ALTER TABLE `ccwiz_sessions`
  MODIFY `Id` int(11) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=44;
--
-- AUTO_INCREMENT for table `ccwiz_technologies`
--
ALTER TABLE `ccwiz_technologies`
  MODIFY `Id` int(11) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=6;
--
-- AUTO_INCREMENT for table `ccwiz_users`
--
ALTER TABLE `ccwiz_users`
  MODIFY `Id` int(11) NOT NULL AUTO_INCREMENT, AUTO_INCREMENT=3;
